import 'package:flutter/material.dart';
import 'package:pc_plugins/widgets/site_preview/site_preview_default.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:pointer_interceptor/pointer_interceptor.dart';

init({required String url,double width=90,double height=100,
  void Function()? onTap,bool loading=false,bool interactive=false,
  bool border=true,Widget Function()? loadingBuilder}) => PdfPreview(
  url: url, width: width,height: height,onTap: onTap,loading: loading,interactive: interactive,
  border: border,loadingBuilder: loadingBuilder,);

class PdfPreview extends StatefulWidget implements SitePreview{
  final String url;
  final double width;
  final double height;
  final bool loading;
  final void Function()? onTap;
  final bool interactive;
  final bool border;
  final Widget Function()? loadingBuilder;

  PdfPreview({
    required this.url,
    this.width = 90,
    this.height = 100,
    this.loading = false,
    this.interactive = false,
    this.onTap,
    this.border = false,
    this.loadingBuilder,
  });

  @override
  _PdfPreviewState createState() => _PdfPreviewState();
}

class _PdfPreviewState extends State<PdfPreview> {
  Color backgroundColor = Colors.transparent;
  late WebViewController _controller;

  Future<void> initializeController() async {
    _controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..setBackgroundColor(const Color(0x00000000))
      ..setNavigationDelegate(
        NavigationDelegate(
          onProgress: (loadingBuilder) => loadingBuilder,
          onWebResourceError: (WebResourceError error) {},
          onNavigationRequest: (NavigationRequest request) {
            return NavigationDecision.navigate;
          },
        ),
      )
      ..loadRequest(Uri.parse(widget.url));
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: widget.width,
      height: widget.height,
      child: Stack(
        children: [
          FutureBuilder<void>(
            future: initializeController(),
            builder: (BuildContext context, AsyncSnapshot<void> snapshot) {
              if (snapshot.connectionState == ConnectionState.done) {
                return WebViewWidget(
                  controller: _controller,
                );
              } else {
                return widget.loadingBuilder!();
              }
            },
          ),
          if (widget.interactive)
            PointerInterceptor(
              child: SizedBox(
                width: widget.width,
                height: widget.height,
                child: ElevatedButton(
                  onPressed: widget.onTap,
                  style: ElevatedButton.styleFrom(
                    backgroundColor: Colors.transparent,
                    elevation: 0,
                  ),
                  child: null,
                ),
              ),
            ),
        ],
      ),
    );
  }
}