import 'dart:html';
import 'package:flutter/material.dart';
import 'package:pc_plugins/widgets/site_preview/site_preview_default.dart';
import 'dart:ui' as ui;
import 'package:pointer_interceptor/pointer_interceptor.dart';


init({required String url,double width=90,double height=100,
  void Function()? onTap,bool loading=false,bool interactive=false,
  bool border=true,Widget Function()? loadingBuilder}) => PdfPreview(
  url: url, width: width,height: height,onTap: onTap,loading: loading,interactive: interactive,
  border: border,loadingBuilder: loadingBuilder,);


void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Center(
          child: PdfPreview(
            url: 'https://res.cloudinary.com/hamlet78/image/upload/v1678149966/trustUs/Adriana%20Cendejas/ts/2023-03-06/Notary%20Fee%202.pdf.pdf',
            width: 100,
            height: 100,
            loading: false,
            interactive: true,
            onTap: () {
              print("Tapped");
            },
            border: false,
            loadingBuilder: () {
              return CircularProgressIndicator();
            },
          ),
        ),
      ),
    );
  }
}

class PdfPreview extends StatefulWidget {
  final String url;
  final double width;
  final double height;
  final bool loading;
  final void Function()? onTap;
  final bool interactive;
  final bool border;
  final Widget Function()? loadingBuilder;

  PdfPreview({
    required this.url,
    this.width = 90,
    this.height = 100,
    this.loading = false,
    this.interactive = false,
    this.onTap,
    this.border = false,
    this.loadingBuilder,
  });

  @override
  _PdfPreviewState createState() => _PdfPreviewState();
}



class _PdfPreviewState extends State<PdfPreview> {
  Color backgroundColor = Colors.transparent;

  @override
  void initState() {
    super.initState();
    ui.platformViewRegistry.registerViewFactory(
      widget.url,
          (int viewId) {
        IFrameElement iframe = IFrameElement()
          ..width = widget.width.toString()
          ..height = widget.height.toString()
          ..src = widget.url
          ..style.border = widget.border ? 'black' : 'none';

        if (!widget.interactive) {
          iframe
            ..style.pointerEvents = 'none'
            ..style.overflow = 'hidden';
        }

        return iframe;
      },
    );
  }


  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: widget.width,
      height: widget.height,
      child: Stack(
        children: [
          HtmlElementView(viewType: widget.url),
          if (widget.interactive)
            PointerInterceptor(
              child: SizedBox(
                width: widget.width,
                height: widget.height,
                child: ElevatedButton(
                  onPressed: widget.onTap,
                  style: ElevatedButton.styleFrom(
                    backgroundColor: Colors.transparent,
                    elevation: 0,
                  ),
                  child: null,
                ),
              ),
            ),
        ],
      ),
    );
  }

}